==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/fileops/translations/fileops_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="93"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="94"/>
        <location filename="../fileops.cpp" line="134"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Тека призначення не існує</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="137"/>
        <source>Move Files</source>
        <translation>Переміщення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="138"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте перемістити %n файл?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файла?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файлів?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <source>Copying</source>
        <translation>Копіювання</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="155"/>
        <location filename="../fileops.cpp" line="249"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="200"/>
        <source>Copying file %1/%2</source>
        <translation>Копіювання файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="248"/>
        <source>Moving</source>
        <translation>Переміщення</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="284"/>
        <source>Moving file %1/%2</source>
        <translation>Переміщення файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="109"/>
        <source>Remove Files</source>
        <translation>Видалення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="110"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте видалити %n файл з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файла з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файлів з диску?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Про модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Модуль роботи з файлами для Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Поміняти комбінацію клавіш</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Натисніть клавіші, комбінацію яких ви бажаєте використовувати</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Переіменувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Нова дія</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation>Перемістити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>Choose a directory</source>
        <translation>Виберіть теку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Налаштування файлових операцій</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Операція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Текст меню</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Комбінація клавіш</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Призначення:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Формат імені файла:</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/fileops/translations/fileops_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="107"/>
        <location filename="../fileops.cpp" line="147"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="108"/>
        <location filename="../fileops.cpp" line="148"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Тека призначення не існує</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="151"/>
        <source>Move Files</source>
        <translation>Переміщення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="152"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте перемістити %n файл?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файла?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файлів?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="174"/>
        <source>Copying</source>
        <translation>Копіювання</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="175"/>
        <location filename="../fileops.cpp" line="269"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="220"/>
        <source>Copying file %1/%2</source>
        <translation>Копіювання файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="268"/>
        <source>Moving</source>
        <translation>Переміщення</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="304"/>
        <source>Moving file %1/%2</source>
        <translation>Переміщення файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="123"/>
        <source>Remove Files</source>
        <translation>Видалення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="124"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте видалити %n файл з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файла з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файлів з диску?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Про модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Модуль роботи з файлами для Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Поміняти комбінацію клавіш</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Натисніть клавіші, комбінацію яких ви бажаєте використовувати</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="216"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="217"/>
        <source>Rename</source>
        <translation>Переіменувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <location filename="../settingsdialog.cpp" line="219"/>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>New action</source>
        <translation>Нова дія</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="181"/>
        <source>Command:</source>
        <translation>Команда:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="218"/>
        <source>Move</source>
        <translation>Перемістити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="220"/>
        <source>Execute</source>
        <translation>Виконати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>Choose a directory</source>
        <translation>Виберіть теку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Налаштування файлових операцій</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <source>Operation</source>
        <translation>Операція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Menu text</source>
        <translation>Текст меню</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>Shortcut</source>
        <translation>Комбінація клавіш</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="127"/>
        <source>Destination:</source>
        <translation>Призначення:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <location filename="../settingsdialog.cpp" line="152"/>
        <source>File name pattern:</source>
        <translation>Формат імені файла:</translation>
    </message>
</context>
</TS>
